utils

package
v0.1.26 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FindAvailablePort

func FindAvailablePort() (uint16, error)

FindAvailablePort finds an available port on localhost

func IsDockerComposeAvailable

func IsDockerComposeAvailable() bool

func IsLocalPath added in v0.1.24

func IsLocalPath(path string) bool

IsLocalPath checks if the given string is a path to a local directory

func ParseKeyValuePairs

func ParseKeyValuePairs(pairs []string) (map[string]string, error)

ParseKeyValuePairs parses KEY=VALUE pairs.

func SanitizeVersion

func SanitizeVersion(version string) string

SanitizeVersion sanitizes a version string for use in filesystem paths. Replaces invalid filesystem characters with hyphens.

Types

This section is empty.

Jump to