Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FindAvailablePort ¶
FindAvailablePort finds an available port on localhost
func IsDockerComposeAvailable ¶
func IsDockerComposeAvailable() bool
func IsLocalPath ¶ added in v0.1.24
IsLocalPath checks if the given string is a path to a local directory
func ParseKeyValuePairs ¶
ParseKeyValuePairs parses KEY=VALUE pairs.
func SanitizeVersion ¶
SanitizeVersion sanitizes a version string for use in filesystem paths. Replaces invalid filesystem characters with hyphens.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.